### Creating sticky notes has never been easier.
[![PyPI_version](https://img.shields.io/pypi/v/noty.svg)](https://pypi.org/project/noty)
[![PyPI download month](https://img.shields.io/pypi/dm/noty.svg)](https://pypi.org/project/noty)
[![GitHub license](https://img.shields.io/github/license/GrgBls/Noty.svg)](https://github.com/GrgBls/noty/blob/master/LICENSE)



### Now available at PyPI: [noty](https://pypi.org/project/noty)

#### :heavy_exclamation_mark: This program will not work with Python2, it only works with Python3

#### Easy and fast installation.


<a href="https://user-images.githubusercontent.com/24195309/55061882-1d087500-5075-11e9-9a6d-4448b40d1767.gif"><img src="https://user-images.githubusercontent.com/24195309/55061882-1d087500-5075-11e9-9a6d-4448b40d1767.gif" title="Noty"/></a>




## Installation
---
#### For ease of installation, it is recommended you use pipx instead of pip.

## Using pipx:

    # Install it
    $ pipx install noty

    # Run it
    $ noty

    # You are now ready to use it!

## Without using pipx:

### Using pip:

    # Install it
    $ pip3 install noty

    # Run it
    $ noty

    # You are now ready to use it!

### Without using pip:

    # Clone the repository
    $ git clone https://github.com/GrgBls/noty.git

    # Move into noty folder.
    $ cd noty

    # Install noty
    $ sudo python3 setup.py install

    # Run it
    $ noty

    # You are now ready to use it!

## How to:

    # Run it
    $ noty #If this doesn't work, try reinstalling using the command sudo.

    # Type your notes
    $ Remember to buy milk.

    # You are now ready to use it.


## Installation requirements.
---
python3

tkinter

pipx
